@@ -298,7 +298,7 @@ void BackgroundDlg::setBackgroundOnPreviewLabel()
     bgPreview = bgPreview.scaled(321,151,Qt::KeepAspectRatio,Qt::FastTransformation);
     m_ui->backgroundPreview->setPixmap(bgPreview);
     backgroundPixmap = bgPreview.scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
-    m_ui->okButton->setEnabled(true); // EHKÄ TURHA
+    m_ui->okButton->setEnabled(true);
 }
 
 void BackgroundDlg::process_line(QString line, const int CONF_TYPE)
