@@ -18,7 +18,7 @@ DownloadRemoteDlg::DownloadRemoteDlg(QWidget *parent, bool remoteStartupOnOff, Q
     client = new QxtXmlRpcClient(this, url);
     connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
     connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString )));
     QList<QVariant> list;
     list.clear();
     alphabeticalId = client->call("getLircDirs",list);
@@ -34,18 +34,6 @@ DownloadRemoteDlg::~DownloadRemoteDlg()
     delete m_ui;
 }
 
-void DownloadRemoteDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
 void DownloadRemoteDlg::getManufacturers(QListWidgetItem* item)
 {
     rangeItemString =item->text();
@@ -79,16 +67,16 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
         m_ui->remoteList->clear();
         m_ui->alphabeticalList->insertItems(0,sList);
     }
-    if (Id == manufacturerId) {
+    else if (Id == manufacturerId) {
         m_ui->manufacturerList->clear();
         m_ui->remoteList->clear();
         m_ui->manufacturerList->insertItems(0,sList);
     }
-    if (Id == modelId) {
+    else if (Id == modelId) {
         m_ui->remoteList->clear();
         m_ui->remoteList->insertItems(0,sList);
     }
-    if (Id == fileId) {
+    else if (Id == fileId) {
         QDir dir;
         if(!dir.exists(devicesPath))
             dir.mkpath(devicesPath);
@@ -98,7 +86,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             QTextStream out(&deviceFile);
             for(int i= 0; i< sList.count();i++) { // Streams only one remote data to file
                 QString line = sList.at(i);
-                out << sList.at(i); // Original line
+                out << sList.at(i); // Original version had only this line.
                 if(line.contains("end remote",Qt::CaseInsensitive))
                     break;
 
@@ -135,7 +123,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             QString para = modelItem;
             if(remoteStartup) {
                 remotestartupdlg = new RemoteStartupDlg(para, this, remoteNames);
-                connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(AddButtonToLayout(QString, QString,QString,QString,QStringList,int)));
+                connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(addButtonToLayout(QString, QString,QString,QString,QStringList,int)));
                 connect(remotestartupdlg,SIGNAL(remoteCreated(QString)),this,SLOT(enableRemoteNameAdding(QString)));
                 connect(remotestartupdlg,SIGNAL(lwClear()),this,SLOT(clearScreenForNewRemote()));
                 remotestartupdlg->exec();
@@ -160,14 +148,13 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
         else {
               if(remoteStartup) {
                         remotestartupdlg = new RemoteStartupDlg(modelItem, this, remoteNames);
-                        connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(AddButtonToLayout(QString, QString,QString,QString,QStringList,int)));
+                        connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(addButtonToLayout(QString, QString,QString,QString,QStringList,int)));
                         connect(remotestartupdlg,SIGNAL(remoteCreated(QString)),this,SLOT(enableRemoteNameAdding(QString)));
                         connect(remotestartupdlg,SIGNAL(lwClear()),this,SLOT(clearScreenForNewRemote()));
                         remotestartupdlg->exec();
                         delete remotestartupdlg;
                    }
 
-
               }
 
               this->close();
@@ -175,19 +162,20 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
 }
 void DownloadRemoteDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void DownloadRemoteDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
-void DownloadRemoteDlg::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList aCommand, int number)
+void DownloadRemoteDlg::addButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList aCommand, int number)
 {
     emit addButtonToLayoutSignalFromRSD(fileNameUnPressed, fileNamePressed, confFileName, buttonText, aCommand, number);
 }
-void DownloadRemoteDlg::enableRemoteNameAdding(const QString &remoteName)
+void DownloadRemoteDlg::enableRemoteNameAdding(QString remoteName)
 {
     emit remoteNameToLayoutWidget(remoteName);
 }
