@@ -2,7 +2,7 @@
 #include "ui_uploaddbdlg.h"
 #include "logindbdlg.h"
 
-UploadDBDlg::UploadDBDlg( QWidget *parent, QString confFile) :
+UploadDBDlg::UploadDBDlg(QWidget *parent,QString confFile) :
     QDialog(parent),
     m_ui(new Ui::UploadDBDlg)
 {
@@ -56,8 +56,8 @@ void UploadDBDlg::on_UploadButton_clicked()
 
 void UploadDBDlg::uploadRemote(QString username,QString pwd)
 {
-    // Writing themes to .conf file//
-    /////////////////////////////////
+    // Writing themes to .conf file
+
     userName = username;
     password = pwd;
     QFile file(remotesPath + fileName + ".conf");
@@ -97,8 +97,7 @@ void UploadDBDlg::uploadRemote(QString username,QString pwd)
         QMessageBox::information(this,"Remote upload","Unable to upload remote.Config file is probably missing background.Please edit remote background and save again.",
                              QMessageBox::NoButton,QMessageBox::NoButton);
     }
-    //Upload remote to database//
-    /////////////////////////////
+    //Upload remote to database
     
     if(uploadable) {
         QByteArray hasharray(QCryptographicHash::hash(fileContent.toUtf8(),QCryptographicHash::Sha1));
@@ -123,15 +122,12 @@ void UploadDBDlg::uploadRemote(QString username,QString pwd)
 
 void UploadDBDlg::processReturnValue(int Id,QVariant data)
 {
-    QStringList sList;
-    if (Id == categoryId) {
-        sList = data.toStringList();
-        m_ui->categoryCombo->addItems(sList);
-    }
-    if (Id == manufacturerId) {
-        sList = data.toStringList();
-        m_ui->manufacturerCombo->addItems(sList);
-    }
+    if (Id == categoryId)
+        m_ui->categoryCombo->addItems(data.toStringList());
+
+    if (Id == manufacturerId)
+        m_ui->manufacturerCombo->addItems(data.toStringList());
+
     if (Id == uploadId) {
 
         //data returns remote id
@@ -151,13 +147,14 @@ void UploadDBDlg::processReturnValue(int Id,QVariant data)
 
 void UploadDBDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",""+ string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10), string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
 void UploadDBDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault",""+ string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
